@@ -1,5 +1,5 @@
 import sys
-import signal
+# import signal
 
 from typing import NoReturn, Callable
 
@@ -64,22 +64,24 @@ class App(Context):
         argv = sys.argv[:]
         if self._headless:
             self._qt_application = QCoreApplication(argv)  # Non-GUI
-            signal.signal(signal.SIGINT, lambda *a: self._qt_application.quit())
+            if sys.platform == 'linux':
+                import signal
+                signal.signal(signal.SIGINT, lambda *a: self._qt_application.quit())
         else:
             self._qt_application = QApplication(argv)
 
-        # icon
-        if self._icon_file:
-            self._window_icon = QtGui.QIcon(self._icon_file)
-            self._qt_application.setWindowIcon(self._window_icon)
+            # icon
+            if self._icon_file:
+                self._window_icon = QtGui.QIcon(self._icon_file)
+                self._qt_application.setWindowIcon(self._window_icon)
 
-        # splash
-        if self._splash_file:
-            pixmap = QtGui.QPixmap(self._splash_file)
-            self._splash = QSplashScreen(pixmap)
-            if self._splash_text:
-                self._set_splash_text(self._splash_text, "#ffffff")
-            self._splash.show()
+            # splash
+            if self._splash_file:
+                pixmap = QtGui.QPixmap(self._splash_file)
+                self._splash = QSplashScreen(pixmap)
+                if self._splash_text:
+                    self._set_splash_text(self._splash_text, "#ffffff")
+                self._splash.show()
 
         # asyncqt
         asyncqt_ui_thread_loop.start_loop()
@@ -91,10 +93,14 @@ class App(Context):
 
         # log
         if self._log_file:
-            logfp = open(self._log_file, 'w')
-            STDERR_STREAMS.add(logfp)
-            STDOUT_STREAMS.add(logfp)
-
+            if sys.platform == 'win32':
+                logfp = open(self._log_file, 'w')
+                STDERR_STREAMS.add(logfp)
+                STDOUT_STREAMS.add(logfp)
+            else:
+                logfp = open(self._log_file, 'a')
+                sys.stdout = logfp
+                sys.stderr = logfp
         self._qt_application.aboutToQuit.connect(self._on_quit)
         self.on_create() # -> create and show the WebView window
         exit_code = self._qt_application.exec_()
@@ -123,3 +129,6 @@ class App(Context):
 
     def get_application_dir_path(self):
         return self._qt_application.applicationDirPath()
+
+    def get_headless(self):
+        return self._headless
