@@ -5,10 +5,10 @@ import os
 from typing import NoReturn, Callable, Any
 
 from PyQt5 import QtCore, QtWidgets
-from PyQt5.QtCore import QUrl, QObject, pyqtSignal, pyqtSlot, QVariant, QDir, QEvent, QPoint
+from PyQt5.QtCore import QUrl, QObject, pyqtSignal, pyqtSlot, QVariant, QDir, QEvent, QPoint, QMimeData
 from PyQt5.QtWidgets import QMainWindow, QWidget, QMessageBox, QFileDialog, QShortcut
-from PyQt5.QtGui import QDragEnterEvent, QDragLeaveEvent, QDropEvent, QKeyEvent, QKeySequence
-from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEngineScript
+from PyQt5.QtGui import QDragEnterEvent, QDragLeaveEvent, QDropEvent, QKeyEvent, QKeySequence, QCloseEvent
+from PyQt5.QtWebEngineWidgets import QWebEngineView, QWebEngineScript, QWebEngineSettings
 from PyQt5.QtWebChannel import QWebChannel
 
 from .asyncqt import run_on_worker_thread
@@ -38,7 +38,7 @@ class MyQWebEngineView(QWebEngineView):
     """
 
     def __init__(self, parent, drop_callback: Callable[[QDropEvent], None], dev_mode: bool):
-        super(MyQWebEngineView, self).__init__(parent)
+        super(QWebEngineView, self).__init__(parent)
         self._drop_callback = drop_callback
         self._dev_mode = dev_mode
 
@@ -54,6 +54,17 @@ class MyQWebEngineView(QWebEngineView):
         self._drop_callback(event)
 
 
+class MyQMainWindow(QMainWindow):
+
+    def __init__(self, parent, on_close_callback: Callable):
+        super(QMainWindow, self).__init__(parent)
+        self._on_close_callback = on_close_callback
+
+    def closeEvent(self, event: QCloseEvent):
+        if self._on_close_callback:
+            self._on_close_callback()
+
+
 class CookiesJar(object):
 
     def __init__(self):
@@ -144,6 +155,7 @@ class BrowserWindow(object):
         self._menus = []
         self._actions = []
         self._setup_ui()
+        self._on_window_close_callback = None
 
     def _setup_ui(self) -> NoReturn:
         self._setup_main_window()
@@ -153,7 +165,7 @@ class BrowserWindow(object):
         self._setup_shortcut_keys()
 
     def _setup_main_window(self) -> NoReturn:
-        self._main_window = QMainWindow()
+        self._main_window = MyQMainWindow(None, self._on_window_close)
         if self._configs['frameless']:
             self._main_window.setWindowFlags(QtCore.Qt.FramelessWindowHint)
         self._widget_ui = Ui_WebViewWindowUI()
@@ -165,6 +177,13 @@ class BrowserWindow(object):
     def get_main_window(self):
         return self._main_window
 
+    def set_on_window_close_callback(self, callback):
+        self._on_window_close_callback = callback
+
+    def _on_window_close(self):
+        if self._on_window_close_callback:
+            self._on_window_close_callback()
+
     def _setup_menus(self) -> NoReturn:
         app_menu = self._configs['menu']
         if app_menu:
@@ -221,7 +240,8 @@ class BrowserWindow(object):
         else:
             self._widget_ui.consoleLogDockWidget.setVisible(False)
 
-
+    def set_style_sheet(self,  style_sheet_dir) -> NoReturn:
+        self._main_window.setStyleSheet(style_sheet_dir)
 
     def _setup_shortcut_keys(self):
         self._shortcut_refresh = QShortcut(QKeySequence('Ctrl+R'), self._main_window)
@@ -404,6 +424,8 @@ class WebView(object):
 
     def _create_web_engine_view(self, parent, object_name: str) -> QWebEngineView :
         web_engine_view = MyQWebEngineView(parent, lambda e: self._on_drop(e), self._dev_mode)
+        settings = QWebEngineSettings.defaultSettings()
+        settings.setAttribute(QWebEngineSettings.LocalContentCanAccessRemoteUrls, True)
         web_engine_view.setAutoFillBackground(False)
         web_engine_view.setStyleSheet("")
         web_engine_view.setUrl(QtCore.QUrl("about:blank"))
@@ -412,7 +434,20 @@ class WebView(object):
         return web_engine_view
 
     def _on_drop(self, event: QDropEvent) -> NoReturn:
-        pass # TODO
+        pos = event.pos()
+        mime_data = event.mimeData() # type:QMimeData
+        files = []
+        if mime_data.hasUrls():
+            urls = mime_data.urls()
+            for url in urls:
+                files.append(url.toLocalFile())
+        logging.info("files %s %s", files, pos)
+        if self._web_bridge:
+            event = {
+                "files": files,
+                "pos": [pos.x(), pos.y()]
+            }
+            self.send_message_to_js({"type": "onDrop", "event": event})
 
     def bind_function(self, js_function_name: str, py_function: Callable) -> NoReturn:
         self._web_bridge.bind_function(js_function_name, py_function)
